#ifndef NT2_INCLUDE_CONSTANTS_PIO_180_HPP_INCLUDED
#define NT2_INCLUDE_CONSTANTS_PIO_180_HPP_INCLUDED

#include <nt2/trigonometric/include/constants/pio_180.hpp>

#endif
